.TH XWFORM 3X
.SH NAME
XwformWidgetClass \- the X Widget's general widget layout
manager
.SH SYNOPSIS
#include <X11/StringDefs.h>
.br
#include <X11/Intrinsic.h>
.br
#include <Xw/Xw.h>
.br
#include <Xw/Form.h>
.SH CLASSES
A Form widget is built from Core, Composite, Constraint and
XwManager classes
.PP
The widget class to use when creating a form is
XwformWidgetClass.
.PP
The class name of Form is Form.
.SH DESCRIPTION
The Form widget is a constraint based manager that provides
a layout language used to establish spatial relationships
between its children and then manipulates these
relationships when the Form is resized, new children are
added to the Form, or its children are resized, unmanaged,
remanaged or destroyed.
.PP
The following list highlights the types of layout control
provided by the form widget.
.TP 5
Spanning Constraints
.br
A widget can be created with a set of constraints such
that it spans the width or height of a form.  This is
often used for the layout of scrollbars and titlebars.
Constraints that cause a widget to span both the width
and height of a form can also be specified.
.TP 5
Row Constraints
.br
Sets of widgets can be set up as a row so that resizing
a form may increase or decrease the spacing between the
widgets.  The form may also make the widgets smaller if
desired, but it will not allow the widgets to overlap.
.TP 5
Column Constraints
.br
Sets of widgets can be displayed in a single column or
in multiple columns.  The form may increase or decrease
the spacing between widgets or resize the widgets, but
it will not allow the widgets to overlap.
.PP
Automatic Form Resizing
.IP "" 5
The form calculates new sizes or positions for its
children whenever they change size or position.  The
new orm size thus generated is passed as a geometry
request to the parent of the form.  The parent can
accept the request or modify it and return it as a
geometry almost.  When a geometry almost is returned by
the parent, the form respecifies the constraints to
match the parent's reply size.
.TP 5
Optimal Child Sizes and Positions
.br
The Form widget also calculates the sizes and positions
of its children to both match the constraints defined
and to match either the initial size of the widget or
the size given when the widget was modified through
XtSetValues.  These values are further constrained to
match a given form size only when the form's size is
being explicitly changed through its resize procedure,
or its parent returns a geometry almost when the form
makes a geometry request.
.TP 5
Managing, Unmanaging and Destroying Children
.br
When a widget within a form is unmanaged or destroyed,
it is removed from the constraint processing and the
constraints are reprocessed to reposition and/or resize
the form and its contents.  Any widgets that referenced
it are rereferenced to the widget that it had been
referencing.  For the unmanaged case, if the widget is
remanaged, the widgets that were previously referencing
it are rereferenced to it, thus preserving the original
layout.
.SH "NEW RESOURCES"
The Form does not add any new resources.  All of the
functionality for the form is tied to its constraint
resources.
.SH "CONSTRAINT RESOURCES"
The following resources are attached to every widget
inserted into Form.  To specify an of these resources within
a .Xdefaults file, drop the XtN from the resource name.
Refer to CONSTRAINT(3X) for a general discussion of
constraint resources.
.IP "" 4
Constraint Resource Set \-\- Children of FORM(3X)
.ti -8
Name               Class              Type      Default
.br
.ti -8
_______________________________________________________________
.br
.ti -8
XtNxRefName        XtCXRefName        String    NULL
.br
.ti -8
XtNxRefWidget      XtCXRefWidget      Widget    the parent form
.br
.ti -8
XtNxOffset         XtCXOffset         int       0
.br
.ti -8
XtNxAddWidth       XtCXAddWidth       Boolean   FALSE
.br
.ti -8
XtNxVaryOffset     XtCXVaryOffset     Boolean   FALSE
.br
.ti -8
XtNxResizable      XtCXResizable      Boolean   FALSE
.br
.ti -8
XtNxAttachRight    XtCXAttachRight    Boolean   FALSE
.br
.ti -8
XtNxAttachOffset   XtCXAttachOffset   int       0
.br
.ti -8
XtNyRefName        XtCYRefName        String    NULL
.br
.ti -8
XtNyRefWidget      XtCYRefWidget      Widget    the parent form
.br
.ti -8
XtNyOffset         XtCYOffset         int       0
.br
.ti -8
XtNyAddHeight      XtCYAddHeight      Boolean   FALSE
.br
.ti -8
XtNyVaryOffset     XtCYVaryOffset     Boolean   FALSE
.br
.ti -8
XtNyResizable      XtCYResizable      Boolean   FALSE
.br
.ti -8
XtNyAttachBottom   XtCYAttachBottom   Boolean   False
.br
.ti -8
XtNyAttachOffset   XtCYAttachOffset   int       0
.br
.TP 5
XtNxRefName XtNyRefName
.br
When a widget is added as a child of the form its
position is determined by the widget it references.
.br
The reference widget must be created before the widget
which references it is created.  These resources allow
the name of the reference widget to be given.  The form
converts this name to a widget to use for the
referencing.  Any widget that is a direct child of the
form or the form widget itself can be used as a
reference widget.
.TP 5
XtNxRefWidget XtNyRefWidget
.br
The application can specify the reference widget as
either a string representing the name of the widget (as
described above) or as the Widget ID value returned
from XtCreateWidget.  This resource is the means by
which a widget ID is specified.
.TP 5
XtNxOffset XtNyOffset
.br
The location of a widget is determined by the widget it
references.  As the default, a widget's position on the
form exactly matches its reference widget's location.
There are two additional pieces of data used to
determine the location.  This resource defines an
integer value representing the number of pixels to add
to the reference widget's location when calculating the
widget's location.
.PP
XtNxAddWidth XtNyAddHeight
.IP "" 5
This resource indicates whether or not to add the width
or height of the reference widget to a widget's
location when determining the widget's position.
.TP 5
XtNxVaryOffset XtNyVaryOffset
.br
When a form is resized, it processes the constraints
contained within its children.  This resource allows
the spacing between a widget and the widget it
references to vary (either increase or decrease) when a
form's size changes.  For widgets that directly
reference the form widget this resource is ignored.
.br
The spacing between a widget and its reference widget
can decrease to 0 pixels if the XtNAddWidth resource is
FALSE or to 1 pixel if XtNAddWidth is TRUE.
.TP 5
XtNxResizable XtNyResizable
.br
This resource specifies whether the form can resize
(shrink) a widget.  When a form's size becomes smaller
the form will resize its children only after all of the
inter-widget spacing of widget's with their VaryOffset
resource set to TRUE.  The form keeps track of a
widgets initial size or size generated through
XtSetValues so that when the form then becomes larger
the widget will grow to it original size and no larger.
.TP 5
XtNxAttachRight XtNyAttachBottom
.br
Widgets are normally referenced from "form left" to
"form right" or from "form top" to "form bottom."  The
attach resources allow this reference to occur on the
opposite edge of the form.  These resources, when used
in conjunction with the varyOffset resources, allow a
widget to float along the right or bottom edge of the
form.  This is done by setting both the Attach and
VaryOffset resources to TRUE.  A widget can also span
the width and height of the form by setting the Attach
resource to TRUE and the VaryOffset resource to FALSE.
.TP 5
XtNxAttachOffset XtNyAttachOffset
.br
When a widget is attached to the right or bottom edge
of the form (through the above resources), the
separation between the widget and the form is defaulted
to 0 pixels.  This resource allows that separation to
be set to some other value.  Also, for widgets that are
not attached to the right or bottom edge of the form,
this constraint specifies the minimum spacing between
the widget and the form.
.SH "INHERITED RESOURCES"
The following resources are inherited from the indicated
superclasses:
.IP "" 17
Core Resource Set \-\- CORE(3X)
.ti -22
Name                   Class                  Type             Default
.br
.ti -22
__________________________________________________________________________
.br
.ti -22
XtNancestorSensitive   XtCSenstitive          Boolean          TRUE
.br
.ti -22
XtNx                   XtCPosition            int              0
.br
.ti -22
XtNy                   XtCPosition            int              0
.br
.ti -22
XtNwidth               XtCWidth               int              0
.br
.ti -22
XtNheight              XtCHeight              int              0
.br
.ti -22
XtNdepth               XtCDepth               int              0
.br
.ti -22
XtNbackground          XtCBackground          Pixel            White
.br
.ti -22
XtNbackgroundPixmap    XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNborderWidth         XtCBorderWidth         int              1
.br
.ti -22
XtNborderColor         XtCBorderColor         Pixel            Black
.br
.ti -22
XtNborderPixmap        XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNsensitive           XtCSensitive           Boolean          TRUE
.br
.ti -22
XtNmappedWhenManaged   XtCMappedWhenManaged   Boolean          TRUE
.br
.ti -22
XtNdestroyCallback     XtCCallback            Pointer          NULL
.br
.ti -22
XtNtranslations        XtCTranslations        XtTranslations   NULL
.br
.IP "" 17
Manager Resource Set
.ti -20
Name                Class               Type      Default
.br
.ti -20
____________________________________________________________
.br
.ti -20
XtNforeground       XtCForeground       Pixel     Black
.br
.ti -20
XtNbackgroundTile   XtCBackgroundTile   int       background
.br
.ti -20
XtNtraversalOn      XtCTraversalOn      Boolean   FALSE
.br
.ti -20
XtNlayout           XtCLayout           int       minimize
.br
.ti -20
XtNnextTop          XtCCallback         Pointer   NULL
.br
.SH "KEYBOARD TRAVERSAL"
If the XtNtraversalOn resource is set to TRUE at either
create time or during a call to XtSetValues, the XwManager
superclass will automatically augment the manager widget's
translations to support keyboard traversal.  Refer to the
XwManager man page for a complete description of these
translations.
.SH EXAMPLES
The following examples list the desired layout of widgets
within a form and the constraints needed to achieve the
layout.
.TP 5
TitleBar
.br
Use the following constraints to get a titlebar widget
to span the top of a form the following constraints can
.IP "" 5
be used.  For a widget named title the .Xdefaults file
will contain.
.IP "" 4
*title.xRefName:        "form widget name"   attach to the left
.ti +45
edge of the form
.br
*title.xOffset:         5                    offset 5 pixels from
.ti +45
the left edge
.br
*title.xResizable:      TRUE                 title is
.ti +45
horizontally
.br
.ti +45
resizable
.br
*title.xAttachRight:    TRUE                 attach to the right
.ti +45
edge of the form
.br
*title.xAttachOffset:   5                    offset 5 pixels from
.ti +45
right edge
.br
*title.yRefName:        "form widget name"   attach to the top
.ti +45
edge of the form
.br
.TP 5
Dynamic Scrolled Window
.br
The above constraints work generally for any widget
type that is to span the form and that need to be
resized as the form increases or decreases in size.
.br
For example, if the child widget is a scrolled window
named sWin that dynamically resizes as the form resizes
in both the horizontal and vertical directions the
constraints are as follows.
.IP "" 4
*sWin.xRefName:        "form widget name"   attach to the left
.ti +44
edge of the form
.br
*sWin.xOffset:         5                    offset 5 pixels from
.ti +44
the left edge
.br
*sWin.xResizable:      TRUE                 scrollWin is
.ti +44
horizontally
.br
.ti +44
resizable
.br
*sWin.xAttachRight:    TRUE                 attach to the right
.ti +44
edge of the form
.br
*sWin.xAttachOffset:   5                    offset 5 pixels from
.ti +44
right edge
.br
.IP "" 4
*sWin.yRefName:        "form widget name"   attach to the top
.ti +44
edge of the form
.br
*sWin.yOffset:         5                    offset 5 pixels from
.ti +44
the left edge
.br
*sWin.yResizable:      TRUE                 scrollWin is
.ti +44
vertically resizable
.br
*sWin.yAttachRight:    TRUE                 attach to the bottom
.ti +44
edge of the form
.br
*sWin.yAttachOffset:   5                    offset 5 pixels from
.ti +44
right edge
.br
.TP 5
Right or Bottom Attached Widgets
.br
For a widget named widget to float along the right or
bottom edge of the form as it is resized the constraint
set is the same as for the titlebar example with the
following changes.
.IP "" 4
*widget.xRefName:     "any widget name"   the widget to the
.ti +42
left of this one
.br
*widget.varyOffset:   TRUE                adjust the spacing
.ti +42
with the reference
.br
.ti +42
widget
.br
.TP 5
Columns of Widgets
.br
A set of widgets within a form can be arranged in
columns by using of the constraint language.  The
following set of constraints sets up two columns of
widgets.  The naming of the widgets for this example is
wI,J where I is the column and J is the row.
.IP "" 8
*w0,0.xRefName:     "form widget name"
*w0,0.xOffset:      5
.br
*w0,0.xResizable:   TRUE
.br
*w0,0.yRefName:     "form widget name"
*w0,0.yOffset:      5
.br
*w0,0.yResizable:   TRUE
.IP "" 8
*w0,1.xRefName:     widget0,0
.br
*w0,1.xResizable:   TRUE
.br
*w0,1.yRefName:     widget0,0
.br
*w0,1.yOffset:      5
.br
*w0,1.yAddHeight:   TRUE
.br
*w0,1.yResizable:   TRUE
.IP "" 8
*w1,0.xRefName:     widget0,0
.br
*w1,0.xOffset:      20
.br
*w1,0.yAddWidth:    TRUE
.br
*w1,0.xResizable:   TRUE
.br
*w1,0.yRefName:     widget0,0
.br
*w1,0.yOffset:      5
.br
*w1,0.yAddHeight:   TRUE
.br
*w1,0.yResizable:   TRUE
.IP "" 8
*w1,1.xRefName:     widget1,0
.br
*w1,1.xResizable:   TRUE
.br
*w1,1.yRefName:     widget1,0
.br
*w1,1.yOffset:      5
.br
*w1,1.yAddHeight:   TRUE
.br
*w1,1.yResizable:   TRUE
.SH ORIGIN
Hewlett-Packard Company.
.SH "SEE ALSO"
CORE(3X), COMPOSITE(3X), CONSTRAINT(3X), XWMANAGERCLASS(3X),
Programming With The HP X Widgets,
.br
Programming With Xt Intrinsics,
.br
Programming With Xlib.
