.TH XWSASH 3X
.SH NAME
XwsashWidgetClass \- an X Widgets utility widget
.SH SYNOPSIS
#include <X11/StringDefs.h>
.br
#include <X11/Intrinsic.h>
.br
#include <Xw/Xw.h>
.br
#include <Xw/Sash.h>
.SH CLASSES
The sash widget is built from the Core and XwPrimitive
classes.
.PP
The widget class to use when creating a sash is
XwsashWidgetClass.  The class name is Sash.
.SH DESCRIPTION
The sash widget is a utility widget used by the vertical
paned manager XwVPaned to control the sizes of the
individual panes.  In its realized form it appears as a
square box of its background color.  When the pointer is
moved into the sash the cursor is changed to the crosshair
cursor.
.PP
Callbacks can be attached to the widget to report selection
(XtNselect) and unselection (XtNrelease).  This widget can
be set to respond to Enter and Leave window events by
highlighting and unhighlighting the sash.  This widget is
also capable of handling  keyboard traversal.  (While you
can traverse to the Sash in the current widget library, Sash
does not handle keyboard input.) See the translations below
for the default traversal keycodes.
.SH "NEW RESOURCES"
The sash widget class defines one additional resource which
is detailed in the table below. The programmer should refer
to the man pages for the sash's superclasses to determine
available resources and their defaults.
.IP "" 19
Sash Resource Set
Name          Class         Type      Default
_____________________________________________
XtNcallback   XtCCallback   caddr_t   NULL
.TP 5
XtNcallback
.br
This is used by the paned window widget to be informed
of button presses and mouse movement associated with
.IP "" 5
the sash.
.SH "INHERITED RESOURCES"
The following resources are inherited from the named
superclasses: The defaults used for the sash when being
created are as follows:
.IP "" 17
Core Resource Set \-\- CORE(3X)
.ti -22
Name                   Class                  Type             Default
.br
.ti -22
__________________________________________________________________________
.br
.ti -22
XtNancestorSensitive   XtCSenstitive          Boolean          TRUE
.br
.ti -22
XtNx                   XtCPosition            int              0
.br
.ti -22
XtNy                   XtCPosition            int              0
.br
.ti -22
XtNwidth               XtCWidth               int              0
.br
.ti -22
XtNheight              XtCHeight              int              0
.br
.ti -22
XtNdepth               XtCDepth               int              0
.br
.ti -22
XtNbackground          XtCBackground          Pixel            White
.br
.ti -22
XtNbackgroundPixmap    XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNborderWidth         XtCBorderWidth         int              1
.br
.ti -22
XtNborderColor         XtCBorderColor         Pixel            Black
.br
.ti -22
XtNborderPixmap        XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNsensitive           XtCSensitive           Boolean          TRUE
.br
.ti -22
XtNmappedWhenManaged   XtCMappedWhenManaged   Boolean          TRUE
.br
.ti -22
XtNdestroyCallback     XtCCallback            Pointer          NULL
.br
.ti -22
XtNtranslations        XtCTranslations        XtTranslations   NULL
.br
.IP "" 10
Primitive Resource Set \-\- XWPRIMITIVE(3X)
.ti -15
Name                    Class                   Type      Default
.br
.ti -15
________________________________________________________________________
.br
.ti -15
XtNforeground           XtCForeground           Pixel     Black
.br
.ti -15
XtNtraversalType        XtCTraversalType        int       highlight_off
.br
.ti -15
XtNhighlightStyle       XtCHighlightStyle       int       pattern_border
.br
.ti -15
XtNhighlightThickness   XtCHighlightThickness   int       0
.br
.ti -15
XtNselect               XtCCallback             Pointer   NULL
.br
.ti -15
XtNrelease              XtCCallback             Pointer   NULL
.br
.SH "KEYBOARD TRAVERSAL"
If the XtNtraversalType resource is set to
highlight_traversal (XwHIGHTLIGHT_TRAVERSAL in an argument
list) at either create time or during a call to XtSetValues,
the XwPrimitive superclass will automatically augment the
primitive widget's translations to support keyboard
traversal.  See the XwPrimitive man page for a complete
description of these translations.  Refer to the
.PP
TRANSLATIONS section in this man page for a description of
the translations local to the sash widget.
.SH TRANSLATIONS
The input to the sash is driven by the mouse buttons.  The
default translation set defining this button is listed
below.  Note that for the specific key symbols used in
traversal, the HP Key Cap which corresponds to this key
symbol appears to the right of the definition.
.IP "" 2
<Btn1Down>:      SashAction(Start, UpperPane)
.br
<Btn2Down>:      SashAction(Start, ThisBorderOnly)
<Btn3Down>:      SashAction(Start, LowerPane)
<Btn1Motion>:    SashAction(Move, Upper)
.br
<Btn2Motion>:    SashAction(Move, ThisBorder)
<Btn3Motion>:    SashAction(Move, Lower)
.br
Any<BtnUp>:      SashAction(Commit)
.br
<EnterWindow>:   enter()
.br
<LeaveWindow>:   leave()
.SH ACTIONS
.TP 5
SashAction(Start, UpperPane):
.br
Change the cursor from the crosshair to an upward
pointing arrow.  Determine the upper pane which will be
adjusted (usually the pane to which the sash is
attached).
.TP 5
SashAction(Start, ThisBorderOnly):
.br
Change the cursor from the crosshair to a double headed
arrow.  The panes that will be adjusted are the pane to
which the sash is attached and the first pane below it
that can be adjusted. Unlike the UpperPane and
LowerPane mode, only 2 panes will be affected.  If one
of the panes reaches its minimum or maximum, adjustment
will stop, instead of finding the next adjustable pane.
.TP 5
SashAction(Start, LowerPane):
.br
Change the cursor from the crosshair to a downward
pointing arrow.  Determine the lower pane which will be
adjusted (usually the pane below the pane to which the
sash is attached).
.TP 5
SashAction(Move, Upper):
.br
Draw a series of track lines to illustrate what the
heights of the panes would be if the Commit action were
invoked.  Determine which widget below the upper pane
can be adjusted and make the appropriate adjustments.
.PP
SashAction(Move, ThisBorder):
.IP "" 5
Draw a series of track lines to illustrate what the
heights of the panes would be if the Commit action were
invoked.  Adjust as needed (and as possible) the upper
and lower panes selected when the SashAction(Start,
ThisBorderOnly) action was invoked.
.TP 5
SashAction(Move, Lower):
.br
Draw a series of track lines to illustrate what the
heights of the panes would be if the Commit action were
invoked.  Determine which widget above the lower pane
can be adjusted and make the appropriate adjustments.
.TP 5
enter:
.br
If the XtNtraversalType resource has been set to
XwHIGHLIGHT_ENTER then the button will be highlighted.
Otherwise no action is taken.
.TP 5
leave:
.br
If the XtNtraversalType resouces has been set to
XwHIGHLIGHT_ENTER then the button will be
unhighlighted.  Otherwise no action is taken.
.SH ORIGIN
Hewlett-Packard Company.
.SH "SEE ALSO"
CORE(3X), XWPRIMITIVE(3X), XWVPANED(3X),
.br
Programming With The HP X Widgets,
.br
Programming With Xt Intrinsics,
.br
Programming With Xlib.
